From 40f78d28a9ab6680b82c84cdf986d652c4127785 Mon Sep 17 00:00:00 2001
From: Campbell Barton <ideasman42@gmail.com>
Date: Wed, 2 Jun 2010 18:01:30 +0000
Subject: [PATCH] filename --> filepath (changed in trunk/svn)

---
 export_unreal_psk_psa.py   |  4 ++--
 import_images_as_planes.py | 12 ++++++------
 io_anim_camera.py          |  2 +-
 io_mesh_raw/__init__.py    |  2 +-
 io_mesh_stl/__init__.py    |  2 +-
 5 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/export_unreal_psk_psa.py b/export_unreal_psk_psa.py
index ed1cfb0fa..0a02bcd97 100644
--- a/export_unreal_psk_psa.py
+++ b/export_unreal_psk_psa.py
@@ -1502,7 +1502,7 @@ class ExportUDKAnimData(bpy.types.Operator):
 def menu_func(self, context):
 	bpy.context.scene.unrealexportpsk = True
 	bpy.context.scene.unrealexportpsa = True
-	default_path = bpy.data.filename.replace(".blend", ".psk")
+	default_path = bpy.data.filepath.replace(".blend", ".psk")
 	self.layout.operator ("export.udk_anim_data", text="Skeleton Mesh / Animation Data (.psk/.psa)").path = default_path
 
 class VIEW3D_PT_unrealtools_objectmode(bpy.types.Panel):
@@ -1567,7 +1567,7 @@ class OBJECT_OT_UnrealExport(bpy.types.Operator):
 			bpy.context.scene.unrealexportpsk = True
 			bpy.context.scene.unrealexportpsa = True
 			print("Exporting ALL...")
-		default_path = bpy.data.filename.replace(".blend", ".psk")
+		default_path = bpy.data.filepath.replace(".blend", ".psk")
 		fs_callback(default_path, bpy.context, False)
 		self.report({'WARNING', 'INFO'}, exportmessage)
 		return{'FINISHED'}	
diff --git a/io_anim_camera.py b/io_anim_camera.py
index 4987ec258..3656852e3 100644
--- a/io_anim_camera.py
+++ b/io_anim_camera.py
@@ -145,7 +145,7 @@ class CameraExporter(bpy.types.Operator):
 
 
 def menu_export(self, context):
-    default_path = bpy.data.filename.replace(".blend", ".py")
+    default_path = bpy.data.filepath.replace(".blend", ".py")
     self.layout.operator(CameraExporter.bl_idname, text="Cameras & Markers (.py)").path = default_path
 
 
diff --git a/io_mesh_raw/__init__.py b/io_mesh_raw/__init__.py
index c7f25a1f6..74b111766 100644
--- a/io_mesh_raw/__init__.py
+++ b/io_mesh_raw/__init__.py
@@ -39,7 +39,7 @@ def menu_import(self, context):
 
 def menu_export(self, context):
     from io_mesh_raw import export_raw
-    default_path = bpy.data.filename.replace(".blend", ".raw")
+    default_path = bpy.data.filepath.replace(".blend", ".raw")
     self.layout.operator(export_raw.RawExporter.bl_idname, text="Raw Faces (.raw)").path = default_path
 
 
diff --git a/io_mesh_stl/__init__.py b/io_mesh_stl/__init__.py
index 2572e409e..38ef0535b 100644
--- a/io_mesh_stl/__init__.py
+++ b/io_mesh_stl/__init__.py
@@ -133,7 +133,7 @@ def menu_import(self, context):
 
 
 def menu_export(self, context):
-    default_path = bpy.data.filename.replace(".blend", ".stl")
+    default_path = bpy.data.filepath.replace(".blend", ".stl")
     self.layout.operator(StlExporter.bl_idname,
                          text="Stl (.stl)").path = default_path
 
diff --git a/import_images_as_planes.py b/import_images_as_planes.py
index 0f5b7d209..6d72fda19 100644
--- a/import_images_as_planes.py
+++ b/import_images_as_planes.py
@@ -202,7 +202,7 @@ def getImage(path):
     # Check every Image if it is already there.
     for image in bpy.data.images:
         # If image with same path exists take that one.
-        if image.filename == path:
+        if image.filepath == path:
             img = image
 
     # Else create new Image and load from path.
@@ -210,7 +210,7 @@ def getImage(path):
         name = path.rpartition('\\')[2].rpartition('.')[0]
         img = bpy.data.images.new(name)
         img.source = 'FILE'
-        img.filename = path
+        img.filepath = path
 
     return img
 
@@ -247,7 +247,7 @@ def getTexture(path, img):
         # If an (image)texture with image exists, take that one...
         if (texture.type == 'IMAGE'
             and texture.image
-            and texture.image.filename == path):
+            and texture.image.filepath == path):
             tex = texture
 
     # ... otherwise create a new one and apply mapping.
@@ -303,7 +303,7 @@ def main(filePath, options, mapping, dimension):
     images = []
     scene = bpy.context.scene
 
     # If "Create from Directory" (no filename or checkbox) ####
     if options['dir'] or not filePath[1]:
         imageFiles = getImageFilesInDirectory(filePath[2], options['ext'])
 
@@ -318,7 +318,7 @@ def main(filePath, options, mapping, dimension):
         # Assign/get all things.
         for img in images:
             # Create/get Texture
-            tex = getTexture(img.filename, img)
+            tex = getTexture(img.filepath, img)
 
             # Create/get Material
             mat = getMaterial(tex, mapping)
@@ -338,7 +338,7 @@ def main(filePath, options, mapping, dimension):
             plane.selected = True
             scene.objects.active = plane
 
     # If "Create Single Plane" (filename and is image)
     else:
         # Deselect all objects.
         bpy.ops.object.select_all(action='DESELECT')
@@ -303,7 +303,7 @@ def main(filePath, options, mapping, dimension):
     scene = bpy.context.scene
 
-    # If "Create from Directory" (no filename or checkbox) ####
+    # If "Create from Directory" (no filepath or checkbox) ####
     if options['dir'] or not filePath[1]:
         imageFiles = getImageFilesInDirectory(filePath[2], options['ext'])
@@ -338,7 +338,7 @@ def main(filePath, options, mapping, dimension):
             scene.objects.active = plane
 
-    # If "Create Single Plane" (filename and is image)
+    # If "Create Single Plane" (filepath and is image)
     else:
         # Deselect all objects.
-- 
GitLab